@@ -3,7 +3,7 @@
 //
 //  This file is part of Linterna Mágica
 //
-//  Copyright (C) 2010, 2011, 2012 Ivaylo Valkov <ivaylo@e-valkov.org>
+//  Copyright (C) 2010, 2011, 2012, 2013 Ivaylo Valkov <ivaylo@e-valkov.org>
 //  Copyright (C) 2010  Anton Katsarov <anton@katsarov.org>
 //
 //  The JavaScript code in this page (or file) is free software: you
@@ -23,7 +23,7 @@
 //  @licend The above is the entire license notice for the JavaScript
 //  code in this page (or file).
 //
-// @source http://linterna-magica.nongnu.org
+// @source http://linternamagica.org
 
 // END OF LICENSE HEADER
 
@@ -46,10 +46,7 @@ LinternaMagica.prototype.create_video_object = function(object_data)
     // -1 = bottom border of the object
     object_data.outer_height = object_data.height-1;
     object_data.height -= this.controls ? 36 : 24;
-
   
-    var toggle_plugin = null;
-
     var id = object_data.linterna_magica_id;
     this.log("LinternaMagica.create_video_object:\n"+
 	     "Creating video object with linterna_magica_id "+id,2);
@@ -76,6 +73,7 @@ LinternaMagica.prototype.create_video_object = function(object_data)
     var container = document.createElement("div");
     var object_tag_wrapper = document.createElement("div");
     var object_tag = document.createElement("object");
+    var message_wrapper = document.createElement("div");
     var message = document.createElement("p");
     var param = document.createElement("param");
 
@@ -122,9 +120,6 @@ LinternaMagica.prototype.create_video_object = function(object_data)
     var site_html5_player =
 	this.find_site_html5_player_wrapper(object_data.parent);
 
-    var toggle_plugin_switch_type = 
-	site_html5_player ? "html5" : "plugin";
-
     object_tag.setAttribute("width", object_data.width);
     object_tag.setAttribute("height", object_data.height);
     object_tag.setAttribute("id","linterna-magica-video-object-"+id);
@@ -142,7 +137,7 @@ LinternaMagica.prototype.create_video_object = function(object_data)
 	// - The UA it sends is different from the browser, Vimeo does
 	// not load.
 	// With video/flv totemCone plugin will load.
-	if (/mp4|m4v|quicktime/i)
+	if (/mp4|m4v|quicktime/i.test(object_data.mime))
 	{
 	    var mp4 = navigator.mimeTypes["video/mp4"];
 	    if (mp4 && mp4.enabledPlugin && mp4.enabledPlugin.name &&
@@ -156,13 +151,114 @@ LinternaMagica.prototype.create_video_object = function(object_data)
 	object_tag.setAttribute("data", object_data.link);
     }
 
-    message.textContent = this._("Waiting for video plugin...");
-    message.style.setProperty("height", object_data.height+"px",
+    message.textContent = this._("Waiting for video plugin to load ...");
+    message_wrapper.setAttribute("class",
+				 "linterna-magica-video-object-messages");
+    message_wrapper.style.setProperty("height", object_data.height+"px",
 				 "important");
 
-    message.style.setProperty("width", object_data.width+"px",
+    message_wrapper.style.setProperty("width", object_data.width+"px",
 				 "important");
 
+    message_wrapper.appendChild(message);
+
+
+    // Firefox Mixed Content blocker
+    // https://savannah.nongnu.org/bugs/?39726
+    if(/https:/i.test(window.location.protocol) &&
+       /http:/i.test(object_data.link))
+    {
+	var message_mixed = document.createElement("p");
+	message_mixed.textContent =
+	    this._("It seems that the page is serving mixed ")+
+	    this._("content and Linterna M\u00e1gica ")+
+	    this._("might not be able to play the video, because ")+
+	    this._("of mixed content blocking.");
+
+	message_wrapper.appendChild(message_mixed);
+
+	var mixed_content = document.createElement("a");
+	mixed_content.textContent =
+	    this._("Read about mixed content blocking in Firefox (forks and clones as well)");
+	mixed_content.setAttribute("href", 
+		       "https://blog.mozilla.org/tanvi/2013/04/10/"+
+		       "mixed-content-blocking-enabled-in-firefox-23/");
+
+	message_mixed = document.createElement("p");
+	message_mixed.appendChild(mixed_content);
+
+	message_wrapper.appendChild(message_mixed);
+
+
+	message_mixed = document.createElement("p");
+	var mixed_addon = document.createElement("a");
+	mixed_addon.setAttribute("href",
+				 "https://addons.mozilla.org/en-us/firefox/"+
+				 "addon/toggle-mixed-active-content/");
+
+	mixed_addon.textContent = 
+	    this._("Check out the Toggle Mixed Active Content addon");
+
+	message_mixed.appendChild(mixed_addon);
+	message_wrapper.appendChild(message_mixed);
+
+	var no_https = document.createElement("a");
+
+	var http_link =  window.location.href.replace("https:", "http:");
+	if (window.location.pathname == '/' &&
+	    (/vimeo/i.test(window.location.host) ||
+	     /vimeo/i.test(window.location.hostname)))
+	{
+	    http_link = object_data.video_id;
+	}
+	no_https.setAttribute("href", http_link);
+
+
+	no_https.textContent =
+	    this._("View the page without encryption on your own risk");
+
+	message_mixed = document.createElement("p");
+	message_mixed.appendChild(no_https);
+	message_wrapper.appendChild(message_mixed);
+    }
+
+    // Bug 39402. Some links have the signature in the s=<SIG>
+    // format. For example when they are oppened from Canada
+    if (this.sites['youtube.com'].encrypted_signature)
+    {
+	object_tag.setAttribute("data", "#");
+	object_tag.setAttribute("type", "#fake");
+
+	var message_enc_sig = document.createElement("p");
+	message_enc_sig.textContent =
+	    this._("It seems that the signatures for this ")+
+	    thhis._("video are encrypted or missing.");
+
+	message_wrapper.appendChild(message_enc_sig);
+
+	message_enc_sig = document.createElement("p");
+	message_enc_sig.textContent =
+	    this._("Linterna M\u00e1gica is not able to play such clips.");
+
+	message_wrapper.appendChild(message_enc_sig);
+
+	message_enc_sig = document.createElement("p");
+	message_enc_sig.textContent =
+	    this._("Sorry for the inconvenience.");
+
+	message_wrapper.appendChild(message_enc_sig);
+
+	var enc_sig_bug = document.createElement("a");
+	enc_sig_bug.textContent =
+	    this._("Read the bug report about encrypted signatures");
+	enc_sig_bug.setAttribute("href",
+				     "https://savannah.nongnu.org/bugs/?39402");
+
+	message_enc_sig = document.createElement("p");
+	message_enc_sig.appendChild(enc_sig_bug);
+
+	message_wrapper.appendChild(message_enc_sig);
+    }
 
     param.setAttribute("name", "autoplay");
     // Find if a clip is already playing.
@@ -196,7 +292,7 @@ LinternaMagica.prototype.create_video_object = function(object_data)
     param.setAttribute("value",  true);
     object_tag.appendChild(param);
 
-    object_tag.appendChild(message);
+    object_tag.appendChild(message_wrapper);
 
     object_tag_wrapper.appendChild(object_tag);
     container.appendChild(object_tag_wrapper);
@@ -216,47 +312,8 @@ LinternaMagica.prototype.create_video_object = function(object_data)
     object_tag.linterna_magica_id =
 	parseFloat(object_data.linterna_magica_id+".1");
 
-    // Add link after the object/embed
-    // this.set_priority() has set this.priority
-    // to self if there is no plugin
     if (this.plugin_is_installed || site_html5_player)
     {
-	toggle_plugin =
-	    this.create_toggle_plugin_link("link-not-in-header", id,
-					  toggle_plugin_switch_type);
-
-	var before = null;
-
-	if (this.plugin_is_installed && !site_html5_player)
-	{
-	    before = this.get_flash_video_object(id) ?
-		this.get_flash_video_object(id) : null;
-	}
-	else if (site_html5_player)
-	{
-	    before = site_html5_player;
-	}
-
-	if (before && before.nextSibling)
-	{
-	    object_data.parent.insertBefore(toggle_plugin, before.nextSibling);
-	}
-	else
-	{
-	    object_data.parent.appendChild(toggle_plugin);
-	}
-
-	if (((this.priority.self > this.priority.plugin) && 
-	     this.plugin_is_installed && !site_html5_player) ||
-	    ((this.priority.self > this.priority.html5) &&
-	     site_html5_player))
-	{
-	    // Hide the toggle plugin button only if self has higher
-	    // priority then plugin and html5.
-	    toggle_plugin.style.setProperty("display", "none",
-					    "important");
-	}
-
 	this.add_css_class(object_data.parent, "linterna-magica-ws-video-parent");
     }
 
@@ -280,11 +337,7 @@ LinternaMagica.prototype.create_video_object = function(object_data)
     }
 
     // Remove/hide the object if it is in DOM
-    if ((((this.priority.self > this.priority.plugin) &&
-	  !site_html5_player) || 
-	 ((this.priority.self > this.priority.html5) &&
-	  site_html5_player)) &&
-	site_player &&
+    if (site_player &&
 	// The object is still in DOM some scripts remove it
 	site_player.parentNode)
     {
@@ -293,44 +346,21 @@ LinternaMagica.prototype.create_video_object = function(object_data)
 	    object_data.use_sibling = site_player.nextSibling;
 	}
 
-	if (!site_html5_player)
-	{
-	    this.hide_flash_video_object(id,site_player.parentNode);
-	}
-	else 
-	{
-	    this.pause_site_html5_player(object_data.parent);
-	    this.hide_site_html5_player(object_data.parent);
-	}
+	site_player.parentNode.removeChild(site_player);
     }
 
-    if (toggle_plugin)
+    if (object_data.use_sibling)
     {
-	object_data.parent.insertBefore(container, toggle_plugin);
+	object_data.parent.insertBefore(
+	    container,
+	    object_data.use_sibling);
     }
     else
     {
-	if (object_data.use_sibling)
+	if (object_data.parent)
 	{
-	    object_data.parent.insertBefore(
-		container,
-		object_data.use_sibling);
+	    object_data.parent.appendChild(container);
 	}
-	else
-	{
-	    if (object_data.parent)
-	    {
-		object_data.parent.appendChild(container);
-	    }
-	}
-    }
-
-    if (((this.priority.self < this.priority.plugin) && 
-	 this.plugin_is_installed) || 
-	((this.priority.self < this.priority.html5) && 
-	 site_html5_player))
-    {
-	this.hide_lm_interface(object_data.linterna_magica_id);
     }
 
     // Objects extracted from script usually does not have cloned object
@@ -380,9 +410,7 @@ LinternaMagica.prototype.create_video_object = function(object_data)
     }
 
     // Init the web controls functions
-    // only if Linterna Mágica has priority
-    if (this.controls &&
-	(this.priority.self > this.priority.plugin))
+    if (this.controls)
     {
 	this.player.init.apply(this,[id]);
     }
