@@ -3,7 +3,7 @@
 //
 //  This file is part of Linterna Mágica
 //
-//  Copyright (C) 2010, 2011, 2012  Ivaylo Valkov <ivaylo@e-valkov.org>
+//  Copyright (C) 2010, 2011, 2012, 2013 Ivaylo Valkov <ivaylo@e-valkov.org>
 //  Copyright (C) 2010  Anton Katsarov <anton@katsarov.org>
 //
 //  The JavaScript code in this page (or file) is free software: you
@@ -23,7 +23,7 @@
 //  @licend The above is the entire license notice for the JavaScript
 //  code in this page (or file).
 //
-// @source http://linterna-magica.nongnu.org
+// @source http://linternamagica.org
 
 // END OF LICENSE HEADER
 
@@ -39,42 +39,46 @@ LinternaMagica.prototype.extract_dailymotion_links = function(data)
     // requests are useless.
 
     var links_re = new RegExp (
-	"sdurl"+
+	"video_url"+
 	    "(\\\"|\\\')*\\\s*(\\\=|\\\:|\\\,)\\\s*(\\\"|\\\')*"+
 	    "(.*(\\\?auth\\\=[A-Za-z0-9\\\-\\\.]+)"+
 	    "(\\\&|\\\"|\\\'){1})\\\,{1}",
 	"i");
 
-    var links = unescape(data).match(links_re);
+    var link = unescape(data).match(links_re);
 
-    if (links && links[0])
+    if (!link || !link[0])
     {
-	// There is not data after the last comma, it is end-of-match.
-	links =  links[0].replace(/,$/, "").split(/,/);
-
-	var hd_links = new Array();
-
-	for (var lnk=0; lnk<links.length; lnk++)
-	{
-	    var link = new Object();
-	    var link_data = links[lnk];
-
-	    link.label = link_data.match(/\w+-\d+x\d+/i);
-	    link.url =  link_data.replace(/\\\//g, "/").replace(
-		    /(\"\s*:\s*\")|(\"\s*|,\s*\")|hdurl|hqurl|sdurl|\}/ig,
-		"").replace(/hd720url|hd1080url/ig,"");
-
-	    this.log("LinternaMagica.extract_dailymotion_links:\n"+
-		     "Extracted link  : "+link.url,4);
-
-	    // We want highest res on top
-	    // but we parse the links from lowest to highest
-	    hd_links.unshift(link)
-	}
-	return hd_links;
+	return null;
     }
 
-    return null;
+    link = link[0].split(":");
+
+    if (!link || !link[1])
+    {
+	return null;
+    }
+
+    link = link[1].split(",");
+
+    if (!link || !link[0])
+    {
+	return null;
+    }
+
+    link = link[0].split("\"");
+
+    if (!link || !link[1])
+    {
+	return null;
+    }
+
+    link = unescape(link[1]);
+
+    this.log("LinternaMagica.create_youtube_links:\n"+
+	     "Extracted link  : "+link,4);
+
+    return link;
 }
 
 LinternaMagica.prototype.sites["dailymotion.com"] = new Object();
@@ -109,16 +113,6 @@ function()
     return true;
 }
 
-LinternaMagica.prototype.sites["dailymotion.com"].process_cookies =
-function()
-{
-    // Dailymotion is processed twice. Once with .dailymotion.com. The
-    // second time with www.dailymotion.com. They set cookies very
-    // strange.  Also they use host= which is not documented anywhere
-    // (DOM 0,1...).
-    return "; domain=.dailymotion.com; path=/; host="+window.location.hostname+"; ";
-}
-
 LinternaMagica.prototype.sites["dailymotion.com"].do_not_force_iframe_detection =
 function()
 {
@@ -129,14 +123,10 @@ function()
     return false;
 }
 
-LinternaMagica.prototype.sites["dailymotion.com"].skip_video_id_extraction =
-function ()
+LinternaMagica.prototype.sites["dailymotion.com"].skip_link_extraction = 
+function()
 {
-    // Can't extract video_id from script when flash is not
-    // isntalled. The video id is always the pathname.
-    var extracted_data = new Object();
-    extracted_data.video_id = window.location.pathname;
-    return  extracted_data;
+    return false;
 }
 
 LinternaMagica.prototype.sites["dailymotion.com"].
@@ -160,19 +150,6 @@ function(object_data)
     // libswfobject_skip_video_id_extraction
     result.address = object_data.video_id;
 
-    this.extract_cookies();
-    this.expire_cookies();
-
-    // For some strange reason the cookie that activates the HTML5
-    // player could not be expired. It must be forced to non-relevant
-    // for the site value. If it is present, the XHR does not get a
-    // flash player version of the page and no data could be
-    // extracted.
-    if (/html5_switch=1/i.test(document.cookie))
-    {
-	document.cookie = "html5_switch=0;";
-    }
-
     return result;
 }
 
@@ -181,7 +158,23 @@ function(args)
 {
     var client = args.client;
     var object_data = args.object_data;
-    
+
+    // With flash plugin installed there might be a DOM object that
+    // holds the flash player
+    var dom_object = document.getElementById("video_player_main");
+
+    if (dom_object)
+    {
+	object_data.linterna_magica_id =
+	    this.mark_flash_object(dom_object);
+    }
+    else
+    {
+	object_data.linterna_magica_id =
+	    this.mark_flash_object("extracted-from-script");
+
+    }
+
     // !this.plugin_is_installed is removed so it could work when
     //  plugin is installed and HTML5 is active.
     if (!object_data.linterna_magica_id && 
@@ -213,53 +206,17 @@ function(args)
 	    object_data.offsetWidht : null ;
     }
 
-    var hd_links = this.extract_dailymotion_links(client.responseText);
-    object_data.link = hd_links ? hd_links[hd_links.length-1].url : null;
-    object_data.hd_links = (hd_links && hd_links.length) ? hd_links : null;
+    object_data.link = this.extract_dailymotion_links(client.responseText);
 
-    // See "A note on cookies"
-    if (/restore/i.test(this.process_cookies))
+
+    if (!object_data.width || !object_data.height || !object_data.link)
     {
-	this.restore_cookies();
+	return null;
     }
 
-    // For some strange reason the cookie that activates the HTML5
-    // player could not be expired. It was forced to non-relevant for
-    // the site value. If it is present, the XHR does not get a flash
-    // player version of the page and no data could be extracted.  It
-    // must be restored.
-    if (/html5_switch=0/i.test(document.cookie))
-    {
-	document.cookie = "html5_switch=1;";
-    }
-
-
-	if (!object_data.width || !object_data.height || !object_data.link)
-	{
-	    return null;
-	}
-
-
     return object_data;
 }
 
-LinternaMagica.prototype.sites["dailymotion.com"].insert_object_after_xhr =
-function(object_data)
-{
-    // Skip the remove_plugin_install_waring in the default object
-    // creation code after XHR. This keeps the HTML5 error screen.
-    if (/html5_switch=1/i.test(document.cookie))
-    {
-	this.log("LinternaMagica.request_video_link_parse response:\n"+
-		 "Creating video object with url: "+object_data.link,1);
-	this.create_video_object(object_data);
-	return false;
-    }
-
-    // Just exit and leave object insertion to the XHR function.
-    return true;
-}
-
 LinternaMagica.prototype.sites["dailymotion.com"].css_fixes =
 function(object_data)
 {
@@ -278,44 +235,6 @@ function(object_data)
 	{
 	    html5_error.style.setProperty("display", "none", "important");
 	}
-
-	// Hide / show on toggle_plugin clicks 
-	var toggle_header =
-	    document.getElementById("linterna-magica-toggle-plugin-header-"+
-				    object_data.linterna_magica_id);
-	var toggle_after =
-	    document.getElementById("linterna-magica-toggle-plugin-"+
-				    object_data.linterna_magica_id);
-
-	var header_fn = function(ev)
-	{
-	    var err_screen  = document.querySelector(".error_screen");
-
-	    if (!err_screen)
-	    {
-		return;
-	    }
-
-	    if (err_screen.style.display)
-	    {
-		err_screen.style.removeProperty("display");
-	    }
-	    else
-	    {
-		err_screen.style.setProperty("display", 
-					     "none", "important");
-	    }
-	};
-
-	if (toggle_header)
-	{
-	    toggle_header.addEventListener("click",header_fn,false);
-	}
-
-	if (toggle_after)
-	{
-	    toggle_after.addEventListener("click",header_fn,false);
-	}
     }
 
     return null;
@@ -346,3 +265,11 @@ function(parent)
 
     return html5_player_element;
 }
+
+
+LinternaMagica.prototype.sites["dailymotion.com"].flash_plugin_installed = 
+function()
+{
+    return this.sites["dailymotion.com"].
+	no_flash_plugin_installed.apply(this,[arguments]);
+}
